# BBG - Databricks
A repositiory for a useful package that will allow us to make querying a lot easier in bbg's databricks. 

The repository wiki can be found here:  [Wiki](https://danielwilczak101.github.io/bbg/)

